(_api_measurement_vector)=
# Measurement Vector

## Base Class
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.measvec.MeasurementVector

```

## Pre-Defined Measurement Vectors
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.measvec.Triplet

```

## Selectors
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.measvec.select
```

## Transformers
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.measvec.log
    skretrieval.retrieval.measvec.mean
    skretrieval.retrieval.measvec.concat
    skretrieval.retrieval.measvec.multiply
    skretrieval.retrieval.measvec.subtract
    skretrieval.retrieval.measvec.add
```
